@@ -734,12 +734,23 @@ pref("network.IDN.whitelist.vn", true);
 // IDN ccTLDs
 // ae, UAE, .<Emarat>
 pref("network.IDN.whitelist.xn--mgbaam7a8h", true); 
-// sa, Saudi Arabia, .<al-Saudiah>
-pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true); 
-// ru, Russian Federation, .<RF>
-pref("network.IDN.whitelist.xn--p1ai", true);
+// cn, China, .<China> with variants
+pref("network.IDN.whitelist.xn--fiqz9s", true); // Traditional
+pref("network.IDN.whitelist.xn--fiqs8s", true); // Simplified
+// hk, Hong Kong, .<Hong Kong>
+pref("network.IDN.whitelist.xn--j6w193g", true);
 // jo, Jordan, .<Al-Ordon>
 pref("network.IDN.whitelist.xn--mgbayh7gpa", true);
+// ru, Russian Federation, .<RF>
+pref("network.IDN.whitelist.xn--p1ai", true);
+// sa, Saudi Arabia, .<al-Saudiah> with variants
+pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true); 
+pref("network.IDN.whitelist.xn--mgberp4a5d4a87g", true);
+pref("network.IDN.whitelist.xn--mgbqly7c0a67fbc", true);
+pref("network.IDN.whitelist.xn--mgbqly7cvafr", true);
+// tw, Taiwan, <.Taiwan> with variants
+pref("network.IDN.whitelist.xn--kpry57d", true);  // Traditional
+pref("network.IDN.whitelist.xn--kprw13d", true);  // Simplified
 
 // gTLDs
 pref("network.IDN.whitelist.biz", true);
@@ -827,7 +838,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 849 "/builds/slave/linux_build/build/modules/libpref/src/init/all.js"
+//@line 860 "/builds/slave/linux_build/build/modules/libpref/src/init/all.js"
 
 // Controls which NTLM authentication implementation we default to. True forces
 // the use of our generic (internal) NTLM authentication implementation vs. any
@@ -1248,15 +1259,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1667 "/builds/slave/linux_build/build/modules/libpref/src/init/all.js"
+//@line 1678 "/builds/slave/linux_build/build/modules/libpref/src/init/all.js"
 
-//@line 2091 "/builds/slave/linux_build/build/modules/libpref/src/init/all.js"
+//@line 2102 "/builds/slave/linux_build/build/modules/libpref/src/init/all.js"
 
-//@line 2294 "/builds/slave/linux_build/build/modules/libpref/src/init/all.js"
+//@line 2305 "/builds/slave/linux_build/build/modules/libpref/src/init/all.js"
 
-//@line 2390 "/builds/slave/linux_build/build/modules/libpref/src/init/all.js"
+//@line 2401 "/builds/slave/linux_build/build/modules/libpref/src/init/all.js"
 
-//@line 2393 "/builds/slave/linux_build/build/modules/libpref/src/init/all.js"
+//@line 2404 "/builds/slave/linux_build/build/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1526,15 +1537,15 @@ pref("ui.panel.default_level_parent", true);
 
 pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 
-//@line 2665 "/builds/slave/linux_build/build/modules/libpref/src/init/all.js"
+//@line 2676 "/builds/slave/linux_build/build/modules/libpref/src/init/all.js"
 
-//@line 2733 "/builds/slave/linux_build/build/modules/libpref/src/init/all.js"
+//@line 2744 "/builds/slave/linux_build/build/modules/libpref/src/init/all.js"
 
-//@line 2759 "/builds/slave/linux_build/build/modules/libpref/src/init/all.js"
+//@line 2770 "/builds/slave/linux_build/build/modules/libpref/src/init/all.js"
 
-//@line 2779 "/builds/slave/linux_build/build/modules/libpref/src/init/all.js"
+//@line 2790 "/builds/slave/linux_build/build/modules/libpref/src/init/all.js"
 
-//@line 2787 "/builds/slave/linux_build/build/modules/libpref/src/init/all.js"
+//@line 2798 "/builds/slave/linux_build/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1571,9 +1582,9 @@ pref("image.cache.timeweight", 500);
 // The default Accept header sent for images loaded over HTTP(S)
 pref("image.http.accept", "image/png,image/*;q=0.8,*/*;q=0.5");
 
-//@line 2829 "/builds/slave/linux_build/build/modules/libpref/src/init/all.js"
+//@line 2840 "/builds/slave/linux_build/build/modules/libpref/src/init/all.js"
 
-//@line 2834 "/builds/slave/linux_build/build/modules/libpref/src/init/all.js"
+//@line 2845 "/builds/slave/linux_build/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
